// hp 5245L (and others) replacement foot
// design simplified in respect to original molded part
// instead of spring loaded release bolt, I use a cylindric screw


$fn=49;

// overall outer x dimension
xo=46;
// overall outer y dimension
yo=36;
// height of base
h1=8.8;

// position of screw
xs=xo-28;

// height of edge guide
h2=2.7;
// x dimension of edge guide
xg=3;

// fillets
fi=1;

translate([0,0,xo]) rotate([0,90,0]) foot();
//cutout_support();

module foot() {
  difference() {
    base();
    diff=3.5;
    translate([8, diff, 1.5])rcube([xo-xg-8, yo-2*diff, h2],fi);
    // lugs
    translate([xo-25-10,0-fi,0]) rcubef([10,3+fi,h1+h2+2],fi);
    translate([xo-25-10,yo-3,0]) rcubef([10,3+fi,h1+h2+2],fi);
    // support stand
    cutout_support();
    translate([0,yo,0]) mirror([0,1,0]) cutout_support();
    // screw
    translate([xs,yo/2,0]) cylinder(d=2.5,h=h1+h2);
  }
}

// base for all cutouts
module base() {
  union() {
    translate([0,0,h2]) rcube([xo, yo, h1],fi);
    translate([xo-xg,0,0]) rcube([xg,yo,h2+2],fi);
    // lugs
    translate([xo-25-9.5,0.5,h1+h2-fi]) rcube([9,6.5,4.6+fi],fi);
    translate([xo-25-9.5,yo-7,h1+h2-fi]) rcube([9,6.5,4.6+fi],fi);
    // lug
    xl=4.7;
    yl=2.75;
    translate([xs+3.5,(yo-yl)/2,h1+h2-fi]) rcube([xl,yl,2.5],fi/2);
  }
}

module cutout_support() {
  d1=5;
  d2=3.5;
  dy=(yo-10.6-d1)/2;
  dx=5.2;
  h3=h2+6;
  difference() {
    union() {
      translate([dx,dy,0]) cylinder(d=d1, h=h1+h2);
      cube([dx,dy+d1/2,h1+h2]);
    }
    translate([d2/2,dy+d1/2,0]) cylinder(d=d2, h=h1+h2);
  }
  translate([dx,0,h3]) rotate([-90,0,0]) cylinder(d=d1,h=dy);
  translate([dx,0,h3]) cube([d1/2,dy,h1/2]);
  //
  translate([dx,dy,h3]) rotate([0,90,0]) cylinder(d=d1,h=h1);
  translate([dx,dy-d1/2,h3]) cube([h1,d1,h1/2]);
  //
  translate([dx+d1,dy-d1,h3]) rotate([0,0,90]) rotate_extrude(angle=90) translate([d1, 0, 0]) circle(d = d1);
  translate([dx,dy-d1,h3-d1]) rotate([0,-90,0]) rotate_extrude(angle=90) translate([d1, 0, 0]) circle(d = d1);
  translate([dx+d1,dy,h3-d1]) rotate([90,-90,0]) rotate_extrude(angle=90) translate([d1, 0, 0]) circle(d = d1);
}

module rcube(dim,r) {
  translate([r,r,r])
    minkowski() {
      cube([dim[0]-2*r,dim[1]-2*r,dim[2]-2*r]);
      sphere(d=2*r);
    }
}

module rcubef(dim,r) {
  translate([r,r,0])
    minkowski() {
      cube([dim[0]-2*r,dim[1]-2*r,dim[2]-r]);
      cylinder(d=2*r, h=r);
    }
}
